import * as angular from 'angular';
const { ADD_CONTENT_BFF_URL } = process.env;
const { PERSONALIZATION_SERVICE_URL } = process.env;
class AddContentTagService {
    Authorization: string;
    /*@ngInject*/
    constructor(
        private $q,
        private $http,
        private TokenService
    ) {
        this.Authorization = this.TokenService.getAuthToken();
    }

    getPersonalizationTags(companyId, userId) {
        const deferred = this.$q.defer();
        this.$http({
            method: 'GET',
            url:`${PERSONALIZATION_SERVICE_URL}/user/${userId}/company/${companyId}/?features=tags`,
            headers: {
                'Authorization': this.Authorization
            }
        })
            .then(response => {
                deferred.resolve(response.data.tags);
            })
            .catch((err) => {
                console.error('error getting personalization: ', err)
                deferred.resolve({})
            });
        return deferred.promise;
    }

    getTagsForCompany(companyId) {
        const deferred = this.$q.defer();
        this.$http({
            method: 'GET',
            url: `${ADD_CONTENT_BFF_URL}/tags/${companyId}`,
            headers: {
                'Authorization': this.Authorization,
            }
        })
            .then(response => {
                deferred.resolve(response.data);
            })
            .catch(deferred.reject);
        return deferred.promise;
    }

    getTagsAndFilterForPersonalization(companyId, userId, preSelectedTags) {
        return this.$q.all([
            this.getPersonalizationTags(companyId, userId), 
            this.getTagsForCompany(companyId)
        ])
            .then(responses => {
                let [tagsToHide, companyTags] = responses

                return companyTags.filter(tag => {
                    let isPreselected = preSelectedTags.indexOf(tag.name) >= 0
                    if(tagsToHide[tag.id] && !isPreselected) {
                        return !tagsToHide[tag.id].hidden;
                    }
                    return true;
                })
            });
    }
    createTag = (tagName) =>{
        let deferred = this.$q.defer();
        this.$http({
            method: 'POST',
            url: `${ADD_CONTENT_BFF_URL}/create-tag`,
            headers: {
                'Authorization': this.Authorization,
            },
            data: JSON.stringify({tagName,})
        })
            .then(response => {
                deferred.resolve(response.data);
            })
            .catch(deferred.reject);
        return deferred.promise;
    }
}

export default AddContentTagService;
