import './create-tag.component.less';

export default class CreateTagComponent {
    workflow: any;
    tagName: string = '';
    tagDisplays: string [];
    createTagError: string;
    creatingTag: boolean;

    static config = {
        selector: 'createTagComponent',
        template: `
        <mw-mini-modal-dialog class="add-content-workflow__tag-create mw-mini-modal-dialog" 
            layout="column"
            title="{{::$ctrl.AddContentTranslate.get('add-content-workflow__create-tag--title')}}"
            no-padding="true">
            <mw-modal-content>
                <div layout="column" class="add-content-workflow__tag-create-form">
                    <md-input-container md-is-error="$ctrl.createTagError">
                        <label>{{::$ctrl.AddContentTranslate.get('add-content-workflow__create-tag--label')}}</label>
                        <input maxlength="255" ng-trim="false" max- wrap="off" md-autofocus ng-model="$ctrl.tagName" name="tagName" />
                        <span class="add-content-workflow__tag-create-counter" class="form-control__character-counter">{{$ctrl.tagName.length}}/255</span>
                        <div ng-messages="$ctrl.workflow.validationErrors" class="add-content-workflow__tag-create-errors">
                            <div>{{$ctrl.AddContentTranslate.get($ctrl.createTagError)}}</div>
                        </div>
                        </md-input-container>
                </div>
            </mw-modal-content>
            <mw-modal-footer layout="row" layout-align="center center" flex>
                <div flex=""></div>
                <md-button ng-click="$ctrl.handleCancel($event)" class="mw-mini-modal__cancel-button mw-button" ng-disabled="$ctrl.creatingTag">{{::$ctrl.AddContentTranslate.get('add-content-workflow__dialog—cancel--button')}}</md-button>
                <md-button ng-click="$ctrl.handleOk()" class="mw-mini-modal__ok-button mw-button md-primary" ng-disabled="$ctrl.creatingTag">
                    <md-progress-circular ng-if="$ctrl.creatingTag"
                        md-diameter="16px"
                        style="margin: 0 auto"></md-progress-circular>
                    <span ng-if="!$ctrl.creatingTag">{{::$ctrl.AddContentTranslate.get('add-content-workflow__tags-modal--save-button')}}</span>
                </md-button>
            </mw-modal-footer>
        </mw-mini-modal-dialog>
        `,
        controller: CreateTagComponent,
        bindings: {
            workflow: '<'
        },
        
    };
    constructor(
        private AddContentTranslate,
        private AddContentTagService,
        private $mdDialog
    ){
    }
    $onInit(){
        this.tagDisplays = this.workflow.tags.map((tag)=> tag.display)
    }
    handleCancel($event){
        this.$mdDialog.cancel()
    }
   handleOk(){
        if(this.tagName !== ''){
            if(this.tagDisplays.indexOf(this.tagName) === -1){
                this.creatingTag = true;
                this.AddContentTagService.createTag(this.tagName)
                    .then((response)=>{
                        let newTag = {
                            display: response.name,
                            selected: true,
                            type: "tag",
                            id: response.id
                        }
                        this.$mdDialog.hide(newTag)
                    })
                    .finally(() => {
                        this.creatingTag = false;
                    })
            } else {
                this.createTagError = 'add-content-workflow__create-tag--duplicate-tag-error';
            }
        } else {
            this.createTagError = 'mw-form-validation__field-required'
        }
    }
}
