export default class InputSelectorDialogComponent {
    workflow: any;
    previouslySelected: any[];
    static config = {
        selector: 'inputSelectorDialog',
        template: `
            <mw-mini-modal-dialog class="add-content-input-selector mw-mini-modal-dialog" 
                layout="column" data="$ctrl.inputs" 
                title="{{::$ctrl.AddContentTranslate.get('add-content-workflow__tags-modal--tag-modal-title')}}" 
                no-padding="true"
                ok="{{::$ctrl.AddContentTranslate.get('add-content-workflow__tags-modal--save-button')}}" 
                cancel="{{::$ctrl.AddContentTranslate.get('add-content-workflow__dialog—cancel--button')}}" 
                on-ok="$ctrl.handleOk($event)" 
                on-cancel="$ctrl.handleCancel($event)">
                    <mw-modal-header>
                        <mw-modal-header-title>{{$ctrl.AddContentTranslate.get('add-content-workflow__tags-modal--tag-modal-title')}} ({{$ctrl.countSelected()}}/{{$ctrl.inputs.length}})</mw-modal-header-title>
                        <div flex=""></div>
                    </mw-modal-header>
                    <mw-modal-find>
                        <mw-find search="$ctrl.searchModel" debounce="300" placeholder="{{::$ctrl.AddContentTranslate.get('mw-collection-search__find')}}"></mw-find>
                    </mw-modal-find>
                    <mw-modal-content class="mw-menu-dialog mw-menu--has-find">
                    <md-button 
                    class="mw-button mw-button--has-icon" 
                    ng-click="$ctrl.showTagSelectModal($event)" 
                    style="margin: 8px 0">
                    <mw-icon svg-icon="content:ic_add_circle_outline_24px"></mw-icon>
                    <span>Create Tag</span>
                    </md-button>
                        <mw-menu-subheader ng-show="$ctrl.searchModel.length && $ctrl.searchModel.length >= $ctrl.minSearchLength">
                            <span ng-if="$ctrl.filterCount() === 0">{{::$ctrl.AddContentTranslate.get('add-content-workflow__tags-modal--search-no-results')}}</span>
                            <span ng-if="$ctrl.filterCount() === 1">{{::$ctrl.AddContentTranslate.get('add-content-workflow__tags-modal--search-one-result')}}</span>
                            <span ng-if="$ctrl.filterCount() > 1">{{ ::$ctrl.AddContentTranslate.get('add-content-workflow__tags-modal--search-results', {numResults: $ctrl.filterCount()}) }} </span>
                        </mw-menu-subheader>
                        <mw-menu-item ng-repeat="input in filteredInputs = ($ctrl.inputs | filter: {type:'tag'} | filter: {display: $ctrl.searchModel})"
                                      aria-label="input.display"
                                      is-selected="input.selected"
                                      on-click="input.selected = !input.selected"
                                      type="multiselect">
                            {{input.display}}
                        </mw-menu-item>
                    </mw-modal-content>
            </mw-mini-modal-dialog>
        `,
        bindings: {
            inputs: '<',
            workflow: '<'
        },
        controller: InputSelectorDialogComponent
    };

    searchModel: string;
    inputs: any;
    minSearchLength: number;

    /*@ngInject*/
    constructor(
        private $mdDialog,
        private $filter,
        private AddContentTranslate
    ) {
        this.searchModel = '';
        this.minSearchLength = 1;
    }
    showTagSelectModal = (event) => {
        const parent = angular.element(document.getElementsByClassName('md-dialog-container')[1]);

        this.$mdDialog.show({
            parent,
            multiple: true,
            autoWrap: false,
            bindToController: true,
            fullscreen: true,
            targetEvent: event,
            locals: {
                inputs: angular.copy(this.workflow.tags),
                workflow: this.workflow
            },
            template:`
                <md-dialog class="mw-mini-modal" aria-label="" layout="column">
                    <create-tag-component class="mw-mini-modal-wrapper" workflow="$ctrl.workflow" inputs="$ctrl.inputs" layout="column"></create-tag-component>
                </md-dialog>
            `,
            controller: 'MwMiniModalDialogController',
            controllerAs: '$ctrl',
        })
            .then(
                (newTag) => {
                    // Add new tag to list
                    let newInputs = [...this.inputs, newTag];
                    let newTags = [...this.workflow.tags, newTag];

                    // Sort tags alphabetically
                    this.inputs = newInputs.sort((a,b) => a.display.localeCompare(b.display));
                    this.workflow.tags = newTags.sort((a,b) => a.display.localeCompare(b.display));
                }
            )
            .catch(error => {
                if (error) {
                    console.error('Error applying tags to add content', error);
                }
            });
    };
    $onInit() {
        // Store currently tag ids for diff when the dialog is closed
        this.previouslySelected = this.workflow.tags.filter(tag => tag.selected).map(tag => tag.id);
    }

    cancel() {
        this.$mdDialog.cancel();
    }

    handleOk(event) {
        this.$mdDialog.hide(this.inputs);
    };

    handleCancel(event) {
        // Unselect any tags selected during the current session
        this.workflow.tags = this.inputs.map(tag => {
            return this.previouslySelected.includes(tag.id)
                && {...tag, selected: true}
                || {...tag, selected: false};
        })

        this.$mdDialog.cancel();
    };

    countSelected() {
        return this.inputs.filter(tag => tag.selected).length;
    }

    filterCount() {
        return this.$filter('filter')(this.inputs, {display: this.searchModel}).length
    }

}
